@@ -30,6 +30,9 @@ impl<T> DigraphNodeRef<T> {
             rc
         }
     }
+    pub fn as_rc(self) -> Option<Arc<DigraphNode<T>>> {
+        self.rc
+    }
     pub fn is_none(&self) -> bool {
         self.rc.is_none()
     }
